@@ -34,33 +34,21 @@ package SNMP::Info::Layer2::C2900;
 
 use strict;
 use Exporter;
-use SNMP::Info::CiscoVTP;
-use SNMP::Info::CDP;
-use SNMP::Info::CiscoStats;
-use SNMP::Info::CiscoConfig;
-use SNMP::Info::Layer2;
+use SNMP::Info::Layer2::Cisco;
 
-@SNMP::Info::Layer2::C2900::ISA = qw/SNMP::Info::CiscoVTP SNMP::Info::CDP
-    SNMP::Info::CiscoStats SNMP::Info::CiscoConfig
-    SNMP::Info::Layer2 Exporter/;
+@SNMP::Info::Layer2::C2900::ISA = qw/SNMP::Info::Layer2::Cisco Exporter/;
 @SNMP::Info::Layer2::C2900::EXPORT_OK = qw//;
 
 use vars qw/$VERSION %FUNCS %GLOBALS %MIBS %MUNGE/;
 
-$VERSION = '3.11';
+$VERSION = '3.31';
 
 %GLOBALS = (
-    %SNMP::Info::Layer2::GLOBALS,     %SNMP::Info::CiscoConfig::GLOBALS,
-    %SNMP::Info::CiscoStats::GLOBALS, %SNMP::Info::CDP::GLOBALS,
-    %SNMP::Info::CiscoVTP::GLOBALS,
+    %SNMP::Info::Layer2::Cisco::GLOBALS,
 );
 
 %FUNCS = (
-    %SNMP::Info::Layer2::FUNCS,
-    %SNMP::Info::CiscoConfig::FUNCS,
-    %SNMP::Info::CiscoStats::FUNCS,
-    %SNMP::Info::CDP::FUNCS,
-    %SNMP::Info::CiscoVTP::FUNCS,
+    %SNMP::Info::Layer2::Cisco::FUNCS,
     'i_name' => 'ifAlias',
 
     # C2900PortEntry
@@ -71,15 +59,12 @@ $VERSION = '3.11';
 );
 
 %MIBS = (
-    %SNMP::Info::Layer2::MIBS,     %SNMP::Info::CiscoConfig::MIBS,
-    %SNMP::Info::CiscoStats::MIBS, %SNMP::Info::CDP::MIBS,
-    %SNMP::Info::CiscoVTP::MIBS, 'CISCO-C2900-MIB' => 'ciscoC2900MIB',
+    %SNMP::Info::Layer2::Cisco::MIBS,
+    'CISCO-C2900-MIB' => 'ciscoC2900MIB',
 );
 
 %MUNGE = (
-    %SNMP::Info::Layer2::MUNGE,     %SNMP::Info::CiscoConfig::MUNGE,
-    %SNMP::Info::CiscoStats::MUNGE, %SNMP::Info::CDP::MUNGE,
-    %SNMP::Info::CiscoVTP::MUNGE,
+    %SNMP::Info::Layer2::Cisco::MUNGE,
 );
 
 sub vendor {
@@ -269,15 +254,7 @@ after determining a more specific class using the method above.
 
 =over
 
-=item SNMP::Info::CiscoVTP
-
-=item SNMP::Info::CDP
-
-=item SNMP::Info::CiscoStats
-
-=item SNMP::Info::CiscoConfig
-
-=item SNMP::Info::Layer2
+=item SNMP::Info::Layer2::Cisco
 
 =back
 
@@ -293,15 +270,7 @@ Part of the v2 MIBs from Cisco.
 
 =head2 Inherited MIBs
 
-See L<SNMP::Info::CiscoVTP/"Required MIBs"> for its MIB requirements.
-
-See L<SNMP::Info::CDP/"Required MIBs"> for its MIB requirements.
-
-See L<SNMP::Info::CiscoStats/"Required MIBs"> for its MIB requirements.
-
-See L<SNMP::Info::CiscoConfig/"Required MIBs"> for its MIB requirements.
-
-See L<SNMP::Info::Layer2/"Required MIBs"> for its MIB requirements.
+See L<SNMP::Info::Layer2::Cisco/"Required MIBs"> for its MIB requirements.
 
 =head1 GLOBALS
 
@@ -321,25 +290,9 @@ Returns 1.  Use vlan indexing.
 
 =back
 
-=head2 Globals imported from SNMP::Info::CiscoVTP
+=head2 Globals imported from SNMP::Info::Layer2::Cisco
 
-See L<SNMP::Info::CiscoVTP/"GLOBALS"> for details.
-
-=head2 Globals imported from SNMP::Info::CDP
-
-See L<SNMP::Info::CDP/"GLOBALS"> for details.
-
-=head2 Globals imported from SNMP::Info::CiscoStats
-
-See L<SNMP::Info::CiscoStats/"GLOBALS"> for details.
-
-=head2 Globals imported from SNMP::Info::CiscoConfig
-
-See L<SNMP::Info::CiscoConfig/"GLOBALS"> for details.
-
-=head2 Globals imported from SNMP::Info::Layer2
-
-See L<SNMP::Info::Layer2/"GLOBALS"> for details.
+See L<SNMP::Info::Layer2::Cisco/"GLOBALS"> for details.
 
 =head1 TABLE METHODS
 
@@ -411,25 +364,9 @@ Gives Admin speed of port
 
 =back
 
-=head2 Table Methods imported from SNMP::Info::CiscoVTP
+=head2 Table Methods imported from SNMP::Info::Layer2::Cisco
 
-See L<SNMP::Info::CiscoVTP/"TABLE METHODS"> for details.
-
-=head2 Table Methods imported from SNMP::Info::CDP
-
-See L<SNMP::Info::CDP/"TABLE METHODS"> for details.
-
-=head2 Table Methods imported from SNMP::Info::CiscoStats
-
-See L<SNMP::Info::CiscoStats/"TABLE METHODS"> for details.
-
-=head2 Table Methods imported from SNMP::Info::CiscoConfig
-
-See L<SNMP::Info::CiscoConfig/"TABLE METHODS"> for details.
-
-=head2 Table Methods imported from SNMP::Info::Layer2
-
-See L<SNMP::Info::Layer2/"TABLE METHODS"> for details.
+See L<SNMP::Info::Layer2::Cisco/"TABLE METHODS"> for details.
 
 =head1 SET METHODS
 
