@@ -36,23 +36,27 @@ use strict;
 use Exporter;
 use SNMP::Info::Layer3;
 use SNMP::Info::MAU;
-use SNMP::Info::LLDP;
 use SNMP::Info::CDP;
+use SNMP::Info::Aggregate;
 
-@SNMP::Info::Layer2::HP::ISA
-    = qw/SNMP::Info::Layer3 SNMP::Info::MAU SNMP::Info::LLDP
-    SNMP::Info::CDP Exporter/;
+@SNMP::Info::Layer2::HP::ISA = qw/
+    SNMP::Info::Aggregate
+    SNMP::Info::Layer3 
+    SNMP::Info::MAU 
+    SNMP::Info::CDP 
+    Exporter
+/;
 @SNMP::Info::Layer2::HP::EXPORT_OK = qw//;
 
 use vars qw/$VERSION %GLOBALS %MIBS %FUNCS %PORTSTAT %MODEL_MAP %MUNGE/;
 
-$VERSION = '3.11';
+$VERSION = '3.31';
 
 %MIBS = (
     %SNMP::Info::Layer3::MIBS,
     %SNMP::Info::MAU::MIBS,
-    %SNMP::Info::LLDP::MIBS,
     %SNMP::Info::CDP::MIBS,
+    %SNMP::Info::Aggregate::MIBS,
     'RFC1271-MIB'    => 'logDescription',
     'HP-ICF-OID'     => 'hpSwitch4000',
     'STATISTICS-MIB' => 'hpSwitchCpuStat',
@@ -67,8 +71,8 @@ $VERSION = '3.11';
 %GLOBALS = (
     %SNMP::Info::Layer3::GLOBALS,
     %SNMP::Info::MAU::GLOBALS,
-    %SNMP::Info::LLDP::GLOBALS,
     %SNMP::Info::CDP::GLOBALS,
+    %SNMP::Info::Aggregate::GLOBALS,
     'serial1'      => 'entPhysicalSerialNum.1',
     'serial2'      => 'hpHttpMgSerialNumber.0',
     'hp_cpu'       => 'hpSwitchCpuStat.0',
@@ -85,8 +89,8 @@ $VERSION = '3.11';
 %FUNCS = (
     %SNMP::Info::Layer3::FUNCS,
     %SNMP::Info::MAU::FUNCS,
-    %SNMP::Info::LLDP::FUNCS,
     %SNMP::Info::CDP::FUNCS,
+    %SNMP::Info::Aggregate::FUNCS,
     'i_type2'   => 'ifType',
 
     # RFC1271
@@ -110,8 +114,8 @@ $VERSION = '3.11';
     # Inherit all the built in munging
     %SNMP::Info::Layer3::MUNGE,
     %SNMP::Info::MAU::MUNGE,
-    %SNMP::Info::LLDP::MUNGE,
     %SNMP::Info::CDP::MUNGE,
+    %SNMP::Info::Aggregate::MUNGE,
     'c_id'   => \&munge_hp_c_id,
 );
 
@@ -121,6 +125,8 @@ $VERSION = '3.11';
 %MODEL_MAP = (
     'J8131A' => 'WAP-420-WW',
     'J8130A' => 'WAP-420-NA',
+    'J9833A' => 'PS1810-8G',
+    'J9834A' => 'PS1810-24G',
     'J8133A' => 'AP520WL',
     'J8680A' => '9408sl',
     'J9091A' => '8212zl',
@@ -135,8 +141,10 @@ $VERSION = '3.11';
     'J8992A' => '6200yl-24G',
     'J4902A' => '6108',
     'J8698A' => '5412zl',
+    'J9851A' => '5412R-zl2',
     'J8719A' => '5408yl',
     'J8697A' => '5406zl',
+    'J9850A' => '5406R-zl2',
     'J8718A' => '5404yl',
     'J4819A' => '5308XL',
     'J4850A' => '5304XL',
@@ -168,8 +176,12 @@ $VERSION = '3.11';
     'J4815A' => '3324XL',
     'J4851A' => '3124',
     'J9729A' => '2920-48G-PoE+',
+    'J9729A' => '2920-48G-PoE+',
+    'J9728A' => '2920-48G',
     'J9728A' => '2920-48G',
     'J9727A' => '2920-24G-PoE+',
+    'J9727A' => '2920-24G-PoE+',
+    'J9726A' => '2920-24G',
     'J9726A' => '2920-24G',
     'J9562A' => '2915-8G-PoE',
     'J9148A' => '2910al-48G-PoE+',
@@ -182,30 +194,41 @@ $VERSION = '3.11';
     'J4903A' => '2824',
     'J9022A' => '2810-48G',
     'J9021A' => '2810-24G',
-    'J4899C' => '2650C',
     'J8165A' => '2650-PWR',
     'J4899B' => '2650-CR',
+    'J4899C' => '2650C',
     'J4899A' => '2650',
-    'J4900C' => '2626C',
     'J8164A' => '2626-PWR',
     'J4900B' => '2626-CR',
+    'J4900C' => '2626C',
     'J4900A' => '2626',
     'J9627A' => '2620-48-PoE+',
     'J9626A' => '2620-48',
-    'J9625A' => '2620-24-PoE+',
     'J9624A' => '2620-24-PPoE+',
+    'J9625A' => '2620-24-PoE+',
     'J9623A' => '2620-24',
     'J9565A' => '2615-8-PoE',
     'J9089A' => '2610-48-PWR',
     'J9088A' => '2610-48',
-    'J9086A' => '2610-24/12PWR',
     'J9087A' => '2610-24-PWR',
+    'J9086A' => '2610-24/12PWR',
     'J9085A' => '2610-24',
     'J8762A' => '2600-8-PWR',
+    'J9780A' => '2530-8-PoE+',
+    'J9777A' => '2530-8G',
+    'J9783A' => '2530-8',
+    'J9778A' => '2530-48-PoE+',
+    'J9853A' => '2530-48G-PoE+-2SFP+',
     'J9772A' => '2530-48G-PoE+',
+    'J9855A' => '2530-48G-2SFP+',
     'J9775A' => '2530-48G',
+    'J9781A' => '2530-48',
+    'J9779A' => '2530-24-PoE+',
+    'J9854A' => '2530-24G-PoE+-2SFP+',
     'J9773A' => '2530-24G-PoE+',
+    'J9856A' => '2530-24G-2SFP+',
     'J9776A' => '2530-24G',
+    'J9782A' => '2530-24',
     'J4813A' => '2524',
     'J9298A' => '2520G-8-PoE',
     'J9299A' => '2520G-24-PoE',
@@ -221,6 +244,8 @@ $VERSION = '3.11';
     'J4817A' => '2312',
     'J9449A' => '1810G-8',
     'J9450A' => '1810G-24',
+    'J9802A' => '1810-8G',
+    'J9803A' => '1810-24G',
     'J9029A' => '1800-8G',
     'J9028A' => '1800-24G',
 );
@@ -524,6 +549,8 @@ sub set_i_vlan_tagged {
     return;
 }
 
+sub agg_ports { return agg_ports_ifstack(@_) }
+
 1;
 __END__
 
@@ -570,8 +597,6 @@ after determining a more specific class using the method above.
 
 =item SNMP::Info::Layer2
 
-=item SNMP::Info::LLDP
-
 =item SNMP::Info::MAU
 
 =back
@@ -797,10 +822,6 @@ Returns what version of STP the device is running.
 
 See documentation in L<SNMP::Info::Layer2/"GLOBALS"> for details.
 
-=head2 Globals imported from SNMP::Info::LLDP
-
-See documentation in L<SNMP::Info::LLDP/"GLOBALS"> for details.
-
 =head2 Globals imported from SNMP::Info::MAU
 
 See documentation in L<SNMP::Info::MAU/"GLOBALS"> for details.
@@ -812,7 +833,7 @@ to a hash.
 
 =head2 Overrides
 
-=over
+=over 4
 
 =item $hp->interfaces() 
 
@@ -840,16 +861,18 @@ Crosses i_name() with $hp->e_name() using $hp->e_port() and i_alias()
 Returns reference to hash of power Ethernet port table entries map back to
 interface index (c<ifIndex>)
 
+=item C<agg_ports>
+
+Returns a HASH reference mapping from slave to master port for each member of
+a port bundle on the device. Keys are ifIndex of the slave ports, Values are
+ifIndex of the corresponding master ports.
+
 =back
 
 =head2 Table Methods imported from SNMP::Info::Layer2
 
 See documentation in L<SNMP::Info::Layer2/"TABLE METHODS"> for details.
 
-=head2 Table Methods imported from SNMP::Info::LLDP
-
-See documentation in L<SNMP::Info::LLDP/"TABLE METHODS"> for details.
-
 =head2 Table Methods imported from SNMP::Info::MAU
 
 See documentation in L<SNMP::Info::MAU/"TABLE METHODS"> for details.
