@@ -38,7 +38,7 @@ use SNMP::Info::Layer3;
 
 use vars qw/$VERSION %GLOBALS %FUNCS %MIBS %MUNGE/;
 
-$VERSION = '3.20';
+$VERSION = '3.31';
 
 %MIBS = (
     %SNMP::Info::Layer3::MIBS,
@@ -72,10 +72,14 @@ $VERSION = '3.20';
     'i_up'          => 'sysInterfaceStatus',
 
     # sysIfxStatTable
-    'i_octet_in'       => 'sysIfxStatHcInOctets',
-    'i_octet_out'      => 'sysIfxStatHcOutOctets',
-    'i_pkts_ucast_in'  => 'sysIfxStatHcInUcastPkts',
-    'i_pkts_ucast_out' => 'sysIfxStatHcOutUcastPkts',
+    'i_octet_in64'       => 'sysIfxStatHcInOctets',
+    'i_octet_out64'      => 'sysIfxStatHcOutOctets',
+    'i_pkts_ucast_in64'  => 'sysIfxStatHcInUcastPkts',
+    'i_pkts_ucast_out64' => 'sysIfxStatHcOutUcastPkts',
+    'i_pkts_mutli_in64'  => 'sysIfxStatInMulticastPkts',
+    'i_pkts_multi_out64' => 'sysIfxStatOutMulticastPkts',
+    'i_pkts_bcast_in64'  => 'sysIfxStatInBroadcastPkts',
+    'i_pkts_bcast_out64' => 'sysIfxStatOutBroadcastPkts',
 
     # sysInterfaceStatTable
     'i_discards_in'  => 'sysInterfaceStatDropsIn',
@@ -115,8 +119,8 @@ sub fan {
     my $ret       = "";
     my $s         = "";
     foreach my $i ( sort { $a <=> $b } keys %$fan_state ) {
-        $ret .= $s . $i . ": " . $fan_state->{$i};
-        $s = ", ";
+        $ret .= $s . $i . ': ' . $fan_state->{$i};
+        $s = ', ';
     }
     return if ( $s eq "" );
     return $ret;
@@ -255,6 +259,37 @@ sub i_vlan_membership {
     return $i_vlan_membership;
 }
 
+sub i_vlan_membership_untagged {
+    my $f5      = shift;
+    my $partial = shift;
+
+    my $index  = $f5->i_index($partial) || {};
+    my $tagged = $f5->sys_vm_tagged()   || {};
+    my $vlans  = $f5->v_index()         || {};
+
+    my $i_vlan_membership = {};
+    foreach my $iid ( keys %$tagged ) {
+        
+        next unless $tagged->{$iid} eq 'false';
+        # IID is length.vlan name index.length.interface index
+        # Split out and use as the IID to get the VLAN ID and ifIndex
+        my @iid_array = split /\./, $iid;
+        my $len       = $iid_array[0];
+        my $v_idx     = join '.', ( splice @iid_array, 0, $len + 1 );
+        my $idx       = join '.', @iid_array;
+
+        # Check to make sure we can map to a port
+        my $p_idx = $index->{$idx};
+        next unless $p_idx;
+
+        my $vlan = $vlans->{$v_idx};
+        next unless $vlan;
+
+        push( @{ $i_vlan_membership->{$idx} }, $vlan );
+    }
+    return $i_vlan_membership;
+}
+
 1;
 __END__
 
@@ -391,6 +426,12 @@ IDs.
     print "Port: $port VLAN: $vlan\n";
   }
 
+=item $f5->i_vlan_membership_untagged()
+
+Returns reference to hash of arrays: key = C<ifIndex>, value = array of VLAN
+IDs.  These are the VLANs which are members of the untagged egress list for
+the port.
+
 =item $f5->v_index()
 
 Returns VLAN IDs
